// Example of a clearly worked problem and reasoning behind it.
// Command-line options to enable stepping and/or reverse video:
// asy [-u stepping=true] [-u reverse=true] slidedemo

orientation=Landscape;

import slide;
settings.tex = "pdflatex";
usersetting();

// Commands to generate optional bibtex citations:
// asy slidedemo
// bibtex slidedemo_
// asy slidedemo
//
bibliographystyle("alpha");
//texpreamble("\usepackage{problempack}"); // optionclash
texpreamble("\usepackage{amsmath}");
texpreamble("\newcommand{\U}[1]{\text{ #1}}      % units shortcut");
texpreamble("\newcommand{\E}[1]{\ensuremath{\cdot 10 ^{#1}}} % exponent shortcut");
texpreamble(bulletcolor("black"));

string eqnstring(string s, real width=100bp)
{
  return minipage("\begin{align*}"+s+"\end{align*}",width);
}
// Override slide.equations to use the prettier align* env from amsmath
void equations(string s, pen p=itempen)
{
  vbox("\begin{align*}"+s+"\end{align*}",p);
}
// Wrap textblock from the textpos package

// Generated needed files if they don't already exist.
asy(nativeformat(),"drawing");

// Optional background color or header:
// import x11colors;
// fill(background,box((-1,-1),(1,1)),Azure);
// label(background,"Header",(0,startposition.y));

pair titlealign = W;
titlepagepen = colorless(titlepagepen);
authorpen = colorless(authorpen);
institutionpen = colorless(authorpen);
pen questionPen = fontsize(18pt);
pen genEqnPen = 0.5*red + fontsize(18pt);
pen partEqnPen = 0.5*blue + fontsize(18pt);
pen solnEqnPen = 0.5*green + fontsize(18pt);
pair solutionposition = startposition-(0,0.5); // paper (-1,-1) to (1,1)

titlepage(title="Solving physics problems:\\ a detailed solution style",
          author="W. Trevor King",
          institution="Drexel University",
          date="\today",
          url="http://www.physics.drexel.edu/$\sim$wking");

title("Presenting solutions in an organized manner");
remark(
"Physics isn't just about getting the ``right answer,'' but also about
demonstrating to others why your answer is right and how you came to
that conclusion.  This solution framework makes your argument clearer,
which will help you as you develop the argument, and others when you
try and teach/convince them.");
remark(
"This layout is along the lines of the homework solution format from my
high-school physics class, and I like it a lot.  However, if you have
another format that works for you, go ahead and use that.  Remember,
the purpose is to make the solution look obvious, with very clear
reasoning, both for you and any potential readers.");

outline("Procedure");
item("Copy down the assigned problem");
item("Draw a picture of the problem, labeling useful quantities");
item("Make a list of relevant formulas");
item("Apply the formulas to the particular cases in the problem");
item("Solve for the unknown quantities");
item("Are your answers reasonable?");

title("Copy down the assigned problem");
remark("This step ensures you read the problem carefully");
currentposition=solutionposition;
remark(
"
{
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);

title("Draw a picture of the problem");
remark(
"This step doublechecks your understanding of the problem, helps you
translate it into your own terms, and makes it clear what quantities
your various symbols refer to.");

currentposition=solutionposition;
remark(
"
{\
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);
//new*
figure("drawing");

title("Make a list of relevant formulas");
remark(
"This is the key step, digging deep into your physics knowledge to
dredge up any appropriate formulas. :p");

currentposition=solutionposition;
remark(
"
{\
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);
figure("drawing");
//new*
pair genEqnPos = currentposition+(-.1,.2);
label(eqnstring("
  R &= \rho \frac{L}{A} \\
  V &= IR \\
  R_{1,2} &= R_1 + R_2 \\
  A &= \pi r^2 = \pi (d/2)^2
", minipagewidth/3), genEqnPos, E, genEqnPen);

title("Apply formulas to patricular cases");
remark(
"Here we simply apply the general equations to the problem at hand, and
look up any constants we don't know.");

currentposition=solutionposition;
remark(
"
{\
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);
figure("drawing");
label(eqnstring("
  R &= \rho \frac{L}{A} \\
  V &= IR \\
  R_{1,2} &= R_1 + R_2 \\
  A &= \pi r^2 = \pi (d/2)^2
", minipagewidth/3), genEqnPos, E, genEqnPen);
//new*
pair partEqnPos = genEqnPos+(0,-.4);
label(eqnstring("
  R_T &= R_c + R_a  &  R_c &= \rho_c \frac{l}{A}  &  R_a &= \rho_a \frac{l}{A} \\
  V_T &= I R_T  &  V_c &= I R_c  &  V_a &= I R_a \\
  \rho_c &= 1.68\E{-8}\U{$\Omega$m} \\
  \rho_a &= 2.65\E{-8}\U{$\Omega$m}
", minipagewidth/1.8), partEqnPos, E, partEqnPen);

title("Solve for the unknown quantities");
remark("From this point out it's just math.");
currentposition=solutionposition;
remark(
"
{\
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);
figure("drawing");
label(eqnstring("
  R &= \rho \frac{L}{A} \\
  V &= IR \\
  R_{1,2} &= R_1 + R_2 \\
  A &= \pi r^2 = \pi (d/2)^2
", minipagewidth/3), genEqnPos, E, genEqnPen);
label(eqnstring("
  R_T &= R_c + R_a  &  R_c &= \rho_c \frac{l}{A}  &  R_a &= \rho_a \frac{l}{A} \\
  V_T &= I R_T  &  V_c &= I R_c  &  V_a &= I R_a \\
  \rho_c &= 1.68\E{-8}\U{$\Omega$m} \\
  \rho_a &= 2.65\E{-8}\U{$\Omega$m}
", minipagewidth/1.8), partEqnPos, E, partEqnPen);
//new*
pair solnEqnPos = genEqnPos+(0.9,-.1);
label(eqnstring("
  R_c &= \rho_c \frac{l}{A} = \rho_c \frac{4l}{\pi d^2} = 0.10654\U{$\Omega$}\\
  R_a &= \rho_a \frac{l}{A} = \rho_a \frac{4l}{\pi d^2} = 0.16870\U{$\Omega$}\\
  R_T &= R_c + R_a = 0.28\U{$\Omega$} \\
  V_T &= IR_T \qquad I = V_T/R_T = 0.31\U{A} \\
  V_c &= IR_c = 33\U{mV} \qquad V_a = IR_a = 52\U{mV}
", minipagewidth/1.8), solnEqnPos, SE, solnEqnPen);

title("Are your answers reasonable?");
remark(
"Yes.  The wire is made out of copper and aluminum, both good
conductors, and has a reasonable length and diameter, so we expect low
resistance.  We also expect the more resistive aluminum to have a
higher resistance and a greater voltage drop.");

currentposition=solutionposition;
remark(
"
{\
17.24) \\
A $10.0\U{m}$ length of wire consists of $5.0\U{m}$ of copper followed
by $5.0\U{m}$ of aluminum, both of diameter $1.0\U{mm}$.  A voltage
difference of $85\U{mV}$ is placed across the composite wire.
(a) What is the total resistance (sum) of the two wires?
(b) What is the currnent through the wire?
(c) What are the voltages across the aluminum part and across the copper part?
}
", questionPen);
figure("drawing");
label(eqnstring("
  R &= \rho \frac{L}{A} \\
  V &= IR \\
  R_{1,2} &= R_1 + R_2 \\
  A &= \pi r^2 = \pi (d/2)^2
", minipagewidth/3), genEqnPos, E, genEqnPen);
label(eqnstring("
  R_T &= R_c + R_a  &  R_c &= \rho_c \frac{l}{A}  &  R_a &= \rho_a \frac{l}{A} \\
  V_T &= I R_T  &  V_c &= I R_c  &  V_a &= I R_a \\
  \rho_c &= 1.68\E{-8}\U{$\Omega$m} \\
  \rho_a &= 2.65\E{-8}\U{$\Omega$m}
", minipagewidth/1.8), partEqnPos, E, partEqnPen);
pair solnEqnPos = genEqnPos+(0.9,-.1);
label(eqnstring("
  R_c &= \rho_c \frac{l}{A} = \rho_c \frac{4l}{\pi d^2} = 0.10654\U{$\Omega$}\\
  R_a &= \rho_a \frac{l}{A} = \rho_a \frac{4l}{\pi d^2} = 0.16870\U{$\Omega$}\\
  R_T &= R_c + R_a = 0.28\U{$\Omega$} \\
  V_T &= IR_T \qquad I = V_T/R_T = 0.31\U{A} \\
  V_c &= IR_c = 33\U{mV} \qquad V_a = IR_a = 52\U{mV}
", minipagewidth/1.8), solnEqnPos, SE, solnEqnPen);

title("Some thoughts");
remark(
"Obviously this formal approach is not neccessary for simple problems
that you can almost do in your head.  However, for more complicated
problems, the extra work of drawing a labeled figure and explicitly
writing out the general equations you use will help you solve the
problem faster by making it very easy to remember what each symbol
means, see where you have information that you haven't used in your
solution yet, and get a good overview of your line of reasoning.");
label("This document was produced using Asymptote.
  {\tt http://asymptote.sourceforge.net/}", (-0.8,-0.8), NE, fontsize(12pt));
